#!/bin/sh
#

#echo "Current directory follows"
#pwd
#echo "Directory contents follows"
#ls

cd /mnt/usb

# Remove backup directories
echo "Removing old ReliaAutorun.log"
error="0"
rm -f ReliaAutorun.log

if [ "$error" -eq "0" ]; then
	echo "Removed old /relia1/tmp"
	echo "Removed old /relia1/tmp" >> ReliaAutorun.log
	rm -rf /relia1/tmp
	export error=$?
fi

# Create backup directories
if [ "$error" -eq "0" ]; then
	echo "Creating /relia1/tmp"
	echo "Creating /relia1/tmp" >> ReliaAutorun.log
	mkdir -p /relia1/tmp
	export error=$?
fi

# Handle enabling or disabling Chinese
allow=1
match=`grep '\[Allow\]' /relia1/Relia1.ini`
if [ "$match" == "" ]; then
	# Not there, append it.
	echo "Appending switch 'AllowChinese=$allow'"
	cp -f /relia1/Relia1.ini /relia1/Relia1.new
	echo "[Allow]" >> /relia1/Relia1.new
	echo "AllowChinese=$allow" >> /relia1/Relia1.new
	cp -f /relia1/Relia1.new /relia1/Relia1.ini
else
	# There, modify it.
	match=`grep 'AllowChinese=1' /relia1/Relia1.ini`
	if [ "$match" == "" ]; then
		echo "Modifying switch to 'AllowChinese=$allow'"
		sed s/AllowChinese=0/AllowChinese=$allow/ /relia1/Relia1.ini > /relia1/Relia1.new
	else
		echo "Modifying switch to 'AllowChinese=$allow'"
		sed s/AllowChinese=1/AllowChinese=$allow/ /relia1/Relia1.ini > /relia1/Relia1.new
	fi
	cp -f /relia1/Relia1.new /relia1/Relia1.ini
fi

# Backup the app's directory.
if [ "$error" -eq "0" ]; then
	echo "Backing up /relia1/Relia1.ini to /relia1/tmp/Relia1.ini"
	echo "Backing up /relia1/Relia1.ini to /relia1/tmp/Relia1.ini" >> ReliaAutorun.log
	cp -f /relia1/Relia1.ini /relia1/tmp
	export error=$?
fi

# Update the program binary.
if [ "$error" -eq "0" ]; then
	echo "Updating MiniRelia program..."
	echo "Updating MiniRelia program..." >> ReliaAutorun.log
	cp -f Update/Relia1 /relia1/tmp
	cp -f Update/version /relia1/tmp
	export error=$?
fi

if [ "$error" -eq "0" ]; then
	echo "Updated MiniRelia program"
	echo "Updated MiniRelia program" >> ReliaAutorun.log
	export error=$?
fi

# Update the Chinese translation.
if [ "$error" -eq "0" ]; then
	echo "Updating Chinese translaton..."
	echo "Updating Chinese translaton..." >> ReliaAutorun.log
	cp -f Update/Relia_ch.qm /relia1/tmp
	export error=$?
fi

if [ "$error" -eq "0" ]; then
	echo "Updated Chinese translation"
	echo "Updated Chinese translation" >> ReliaAutorun.log
	export error=$?
fi

if [ "$error" -ne "0" ]; then
	# The update failed, possibly because the USB device went away.
	echo "Update failed with error $error"
	echo "Update failed with error $error" >> ReliaAutorun.log
	rm -rf /relia1/old
	mv /relia1/tmp /relia1/old
	sync
	sleep 1
	sync
	exit 199
fi

# Succeeded, so make /relia1/tmp /relia1
echo "Update succeeded, starting copy to relia1..."
echo "Update succeeded" >> ReliaAutorun.log
echo "Copying Relia..."
echo "Copying Relia..." >> ReliaAutorun.log
cp -f /relia1/tmp/Relia1 /relia1
echo "Copying Relia1.ini..."
echo "Copying Relia1.ini..." >> ReliaAutorun.log
cp -f /relia1/tmp/Relia1.ini /relia1
echo "Copying Relia_ch.qm..."
echo "Copying Relia_ch.qm..." >> ReliaAutorun.log
cp -f /relia1/tmp/Relia_ch.qm /relia1
echo "Copying version..."
cp -f /relia1/tmp/version /relia1

# Request reboot since we updated the binary AND control scripts.
echo "Copy complete, requesting reboot"
echo "Requesting reboot" >> ReliaAutorun.log
sync
sleep 1
sync
exit 100

# Alternatively if only the program binary was changed.
# echo "Requesting restart"
# echo "Requesting restart" >> ReliaAutorun.log
# exit 110

# End of file.

